

% Exercise 3: Temperature estimation considering the dependence of the
% conductivity on temperature (K=1/a+bT)

% Define the input parameters (taken from the previous excercise: Initial T
% (T0), Surface heat flow(Q0), Reduced surface heta flow (Qa), Radiogenic
% heat production (A), Depth (z), Thickness of the layer enriched (D)

T0=0;
Q0=70*10^-3;
Qa=30*10^-3;
A=2.25*10^-6;
z=[0:500:35000];
D=6.2*10^3;

% Define the coefficients of the conductivity equation (< 700 C) for the
% upper crust (0-20 km)

a=0.33;
b=0.33*10^-3;

% Define the coefficients of the conductivity equation (< 700 C) for the
% lower crust (20:35 km)

a1=0.42;
b1=0.29*10^-3;

% Estimate the temperature for the upper crust and lower crust

% Find the values of the depth corresponding to the upper and lower crust
z1=find(z < 20000);
z2=find(z >= 20000);

% Estimate the temperature for the upper crust using a constant value of A 
    
    T1uc=((T0+Q0.*z(z1).*a)-(A.*z(z1).^2.*a./2))./(1-Q0.*z(z1).*b+(A.*z(z1).^2.*b./2));
    
% Estimate the temperature for the upper crust using an exponential reduction  of A 
    
    T2uc=(T0+D.^2.*A.*a-D.^2.*A.*a.*exp(-z(z1)./D)+Qa.*z(z1).*a)./(1-D.^2.*A.*b+D.^2.*A.*b.*exp(-z(z1)./D)-Qa.*z(z1).*b);
    
% Estimate the temperature for the lower crust using a constant value of A 
    
    T1lc=((T0+Q0.*z(z2).*a1)-(A.*z(z2).^2.*a1./2))./(1-Q0.*z(z2).*b1+(A.*z(z2).^2.*b1./2));
    
% Estimate the temperature for the lower crust using an exponential reduction  of A 
    
    T2lc=(T0+D.^2.*A.*a1-D.^2.*A.*a1.*exp(-z(z2)./D)+Qa.*z(z2).*a1)./(1-D.^2.*A.*b1+D.^2.*A.*b1.*exp(-z(z2)./D)-Qa.*z(z2).*b1);

% Find the values of temperature < = 700C

Tfuc1=find(T1uc<700);
Tflc1=find(T1lc<700);
Tfuc2=find(T2uc<700);
Tflc2=find(T2lc<700);

% plot the results 
figure

if Tfuc1 ~=0 
    TempUC1=T1uc(Tfuc1);
        subplot(1,2,1);
    plot(TempUC1,z1(Tfuc1)./-2)
else
end

if Tflc1 ~=0
    TempLC1=T1lc(Tflc1);
    hold on
    plot(TempLC1,z2(Tflc1)./-2)
     
else
end

% Create xlabel
xlabel('Temperature (C)','FontSize',20,'FontWeight','bold');
% Create ylabel
ylabel('Depth (km)','FontSize',20,'FontWeight','bold');
% Create legend
legend({'Upper Crust','Lower Crust'},'FontSize',20,'FontWeight','bold')
title(['T for a constant value of A'],'FontSize',20)

if Tfuc2 ~=0 
    TempUC2=T2uc(Tfuc2);
    subplot(1,2,2)
    plot(TempUC2,z1(Tfuc2)./-2)
else
end

if Tflc2 ~=0
    TempLC2=T2lc(Tflc2);
    hold on
    plot(TempLC2,z2(Tflc2)./-2)
    
else
end

% Create xlabel
xlabel('Temperature (C)','FontSize',20,'FontWeight','bold');
% Create ylabel
ylabel('Depth (km)','FontSize',20,'FontWeight','bold');
% Create legend and add the title
legend({'Upper Crust','Lower Crust'},'FontSize',20,'FontWeight','bold')
title(['T for an exponential decrease of A'],'FontSize',20)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% find the temperature when it is not explicit (for a certain range:0-700C)

% Verify for the linear equation

% Initialize the matrix of the temperature 

MagT0=zeros(7001,1);

% Define the specific depth for which I want to estimate  (e.g., z=1000 m)
z3=find(z==10000);
z4=z(z3);
T3=TempUC1(z3);
T4=TempUC2(z3);

% Estimate the possible values of T for which T01~0

for T=0:0.1:700
    
T01=T-(((Q0.*z4.*a)-(A.*z4.^2.*a./2))./(1-Q0.*z4.*b+(A.*z4.^2.*b./2)));
MagT0(round((T+0.1).*10),:)=T01;

end

% find the value of T for which T01~0

Tfin=find(MagT0==(min(abs(MagT0))));
if Tfin ~=0
    Tfin=Tfin./10;
else
Tfin=(find(MagT0==(min(abs(MagT0)))*-1))./10;
end


% Verify for the exponential equation

% Initialize the matrix of the temperature 

MagT01=zeros(7001,1);

% Estimate the possible values of T for which T02~0

for T=0:0.1:700
    
T02=T-(D.^2.*A.*a-D.^2.*A.*a.*exp(-z4./D)+Qa.*z4.*a)./(1-D.^2.*A.*b+D.^2.*A.*b.*exp(-z4./D)-Qa.*z4.*b);
MagT01(round((T+0.1).*10),:)=T02;

end

% find the value of T for which T02~0

Tfin2=find(MagT01==(min(abs(MagT01))));
if Tfin2 ~=0
    Tfin2=Tfin2./10;
else
Tfin2=(find(MagT01==(min(abs(MagT01)))*-1))./10;
end
