

% Exercise 3: Temperature estimation considering the dependence of the
% conductivity on temperature (K(T)=K0/(0.99+T(a-b/K0))

% Define the input parameters (taken from the previous excercise: Initial T
% (T0), Surface heat flow(Q0), Reduced surface heta flow (Qa), Radiogenic
% heat production (A), Depth (z), Thickness of the layer enriched (D)

T0=0;
Q0=70*10^-3;
Qa=30*10^-3;
A=1.25*10^-7;
z=[0:500:35000];
D=6.2*10^3;

% Define the coefficients of the conductivity equation 

a=0.0030; 
b=0.0042;
c=0.99;
K0=3;

% Estimate the temperature for the  crust using a constant value of A 

    T1=((T0+Q0.*z.*c./K0)-(A.*z.^2.*c./2*K0))./(1-Q0.*z.*((a-b)/K0)./K0+(A.*z.^2.*((a-b)/K0)./2*K0));
    
% Estimate the temperature for the upper crust using an exponential reduction of A 
    
    T2=(T0+D.^2.*A.*c./K0-D.^2.*A.*c./K0.*exp(-z./D)+Qa.*z.*c./K0)./(1-D.^2.*A.*(((a-b)/K0))./K0+D.^2.*A.*(((a-b)/K0))./K0.*exp(-z./D)-Qa.*z.*((a-b)/K0)./K0);
    
    figure
    plot(T1,z./-10^3)
     hold on
    plot(T2,z./-10^3)
    
    % Create xlabel
xlabel('Temperature (C)','FontSize',20,'FontWeight','bold');
% Create ylabel
ylabel('Depth (km)','FontSize',20,'FontWeight','bold');
% Create legend
legend({'T for a constant value of A','T for an exponential decrease of A'},'FontSize',20,'FontWeight','bold')

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% find the temperature when it is not explicit (for a certain range:0-1300C)

z3=find(z==10000);
z4=z(z3);
T3=T1(z3);
T4=T2(z3);


Ao=1.25*10^-7;
Qo=70*10^-3;

a=0.0030; 
b=0.0042;
c=0.99;
K0=3;

% Initialize the matrix of the temperature and conductivity
MagT01=zeros(13001,1);
MagK=zeros(13001,1);

% Estimate the temperature

for Tz1=0:0.1:1300
    
K=K0./(((a-b)./K0)*Tz1+c);
MagK(round((Tz1+0.1).*10),:)=K;

T01=Tz1-(((Qo./K).*z4)-((Ao./2*K).*z4.^2));
MagT01(round((Tz1+0.1).*10),:)=T01;

end
Tfin=find(MagT01==(min(abs(MagT01))));
if Tfin ~=0
    Tfin=Tfin./10;
else
Tfin=(find(MagT01==(min(abs(MagT01)))*-1))./10;
end

% Initialize the matrix of the temperature 
MagT0=zeros(13001,1);

% Estimate the temperature using an exponential decreasing of the heat
% generation

for Tz2=0:0.1:1300
K=K0./(((a-b)./K0)*Tz2+c);
T02=Tz2-(((D^2*Ao)/K)*(1-exp(-z4/D))+(Qa/K).*z4); 
MagT0(round((Tz2+0.1).*10),:)=T02;
end

Tfin2=find(MagT0==(min(abs(MagT0))));
if Tfin2 ~=0
    Tfin2=Tfin2./10;
else
Tfin2=(find(MagT0==(min(abs(MagT0)))*-1))./10;
end


% Plot the conductivity as function of tempeature

Tz2a=[0:0.1:1300];

figure
plot(Tz2a,MagK)
% Create xlabel
xlabel('Temperature (C)','FontSize',20,'FontWeight','bold');
% Create ylabel
ylabel('Conductivity (W/mK)','FontSize',20,'FontWeight','bold');
% creat title
title(['(K(T)=K0/(0.99+T(a-b/K0))'],'FontSize',20)
   
    
    
    

