% Calcolare la temperatura (Ty) in funzione della profondita’ nella 
% sequenza sedimentaria raffigurata, considerando i seguenti spessori: 
% l1=500m, l2=1000m, l3=800m, l4=1000m, l5=1700m.
% Fare un plot della temperatura in funzione della profondit
% (in cooperation with Francesca Maddaloni)

% Write the input paramters (Residual heat flow, Initial T, thickness of
% sediments, thickness of each layer, conductivity and heat generation of
% each layer

% Define the input parameters

Qm=30*10^-3;
T0=10;

L=[500 1000 800 1000 1700];
K=[6.0 3.35 1.6 7.0 3.1];
A=[2.0 1.0 4.0 0.5 5.0]*10^-6;

% Estimate the depth of each layer

zc=cumsum(L);

% write the number of layers
nstrati=5;

% Define the initial conditions (T,z)
T=T0;
z0=0;

% Initialize the vector of temperature and depth and include the initial conditions  
FraT=zeros(nstrati+1,1);
z=zeros(nstrati+1,1);
FraT(1)=T0;
z(1)=0;

% Estimate the temperature at the base of each layer

 for n=1:nstrati
T=T+((Qm+A(n)*zc(n))/K(n))*L(n)-(A(n)/2*K(n)).*L(n)^2;
FraT(n+1,1)=T;

% Create the vector of the depth

z0=z0+L(n);
z(n+1,1)=z0;
 end
 
 % Plot the results
 
figure
plot(FraT,-z,'-o')
xlabel('Temperature (C)','FontSize',20,'FontWeight','bold');
ylabel('Depth (m)','FontSize',20,'FontWeight','bold');
title('Geotherm');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Esercizio 5_2

A1=min(A);
K1=min(K);
zc1=5000;
he=500;
hb=500;

Depth=[0:100:5000];
MagNewT1=zeros(51,1);

NewT1=T0+((Qm+A1.*(zc1-he))/K1).*Depth-(A1/2*K1).*Depth.^2;
NewT2=T0+((Qm+A1.*(zc1+hb))/K1).*Depth-(A1/2*K1).*Depth.^2;

figure

plot(NewT1,Depth.*-1);
hold  on
plot(NewT2,Depth.*-1);

% Create xlabel
xlabel('Temperature (C)','FontSize',20,'FontWeight','bold');

% Create ylabel
ylabel('Depth (m)','FontSize',20,'FontWeight','bold');

% Create legend
legend({'T in case of erosion(500m)','T in case of deposition (500m)'},'FontSize',20,'FontWeight','bold')

